#! /bin/csh -f
#
#  Prototype SOLVE script from Scaler Elves
#
############################
#
#  You can run SOLVE interactively by typing:
#   setenv SOLVEDIR /home/programs/solve
#   /home/programs/solve/solve
#
#   ... and then feeding it lines starting with "title" below
#
#  The f' and f'' values here were taken from the CCP4 crossec program
#  The SOLVE homepage/manual is at:
#  netscape http://www.solve.lanl.gov/
#
############################
set nawk = /bin/awk
$nawk 'BEGIN{print}' >& /dev/null
if($status) set nawk = awk
alias nawk $nawk

setenv SOLVEDIR /home/programs/solve

echo "Output will be put in solve.log and mad.log"
echo "watch solve.status for the sites."
echo ""
echo "enter Cntrl-Z and bg to background this SOLVE job."
echo ""
echo ""

/home/programs/solve/solve << EOF-solve >! solve.log
title Scaler Elves

CELL 78.3 78.3 243.22 90 90 120
symfile ./p6322.sym

resolution 2.52 121.268
res_phase 2 121.268    ! sometimes works better without noisy hi-res data

logfile mad.log                 ! write out most information to this file.
				! summary info will be written to "solve.prt"

mad_atomname Se               ! anomalously scattering atom

!fixscattfactors                 ! do not refine scattering factors
refscattfactors                 ! refine scattering factors
thorough


lambda 1			! info on wavelength #1 follows
label FP			! a label for this wavelength
rawmadfile ../FP.unmerged.fmt	! datafile with h k l I+ sigma+ I- sigma-
wavelength 0.9797		! wavelength value (12654.9 eV)
fprimv_mad -7.8745		! f' value of Se at 12654.9 eV   (IMPORTANT!)
fprprv_mad 3.846		! f" value of Se at 12654.9 eV   (IMPORTANT!)


!premerged
unmerged
readformatted
nres 373			! approx # of residues in ASU         (IMPORTANT!)
nanomalous 8			! approx # of anomalously scattering atoms in ASU (IMPORTANT!)

SAD
! SCALE_MAD                       ! read in and localscale the data
! ANALYZE_MAD                     ! run MADMRG and MADBST and analyze all the Pattersons
! SOLVE                           ! Solve the structure

EOF-solve
############################
if($status) goto bad

grep "TOP SOLUTION FOUND BY SOLVE" solve.status >& /dev/null
if($status) goto bad

touch solve.log
echo "A message from the Elves: "                                         >> solve.log
nawk '/STATUS:   DONE  /,/EOF/' solve.status                              >> solve.log
echo "You might get better results with more accurate f' and f'' in $0."  >> solve.log
echo "the refined values used this time were:"                            >> solve.log
nawk '/NEWATOMTYPE/{print $NF} \
      /FPRIMV/{print "fprimv_mad", $NF} \
      /FPRPRV/{print "fprprv_mad ", $NF}' solve*.script                  >> solve.log
cat << EOF                                                                >> solve.log
a phased MTZ file using this solution should be available in solve.mtz
but, solvent-flattening is highly recommended before you look at maps.
Elves also suggest you put the above sites into SHARP, since it is a
very good phasing program.
EOF

# display message, for those who are listening
tail -500 solve.log | nawk '/A message from the Elves/,/\n/'

exit

bad:
echo "Dang!  SOLVE failed. "
echo "You might need to edit $0 "
echo "to see what went wrong type:  more solve.log"
exit 9

