#! /bin/csh -fe
#
#  Conversion script to output I+ and I- in SOLVE format
#
set nawk = /bin/awk
$nawk 'BEGIN{print}' >& /dev/null
if($status) set nawk = awk
alias nawk $nawk
#
set infile   = ""
set outfile  = "SOLVE.fmt"
set tempfile = "/tmp/jamesh/scaler_temp1216.mtz2solve"
#
goto Setup
#
# usage: ./SOLVE/mtz2SOLVE.com blah.mtz
#
#   if blah.mtz is a merged mtz, then H, K, L, I(+), SIGI(+), I(-), SIGI(-) 
#	will be written to $outfile
#   if blah.mtz is an unmerged mtz, then  H, K, L, I, SIGI
#	will be written to $outfile
#
ReturnFromSetup:

##############################################################
if("$type" == "un") then
# this is the mtz2various format to use, you need 
mtz2various hklin $infile hklout $outfile << EOF-solve
OUTPUT USER '($format)'
LABIN $LABIN
END
EOF-solve
else

# mtz2various doesn't work for this, use mtzutils/mtzdump instead
mtzutils hklin1 $infile hklout ${tempfile}dumpme.mtz << EOF-label
INCLUDE $LABELS
EOF-label

mtzdump hklin ${tempfile}dumpme.mtz << EOF-dump |\
  nawk '/LIST OF REFLECTIONS/,/MTZDUMP/' | nawk 'NF>3 && ! /[A-Z]/' >! $outfile
FORMAT '($format)'
NREF -1
EOF-dump

endif

############################
if(! $status) then
    echo ""
    echo "$outfile now contains $I from $infile in SOLVE format."
    echo "use readformatted and ${type}merged in SOLVE"
    echo ""
endif

exit

Setup:
foreach arg ( $* )
    if((! -e "$infile")&&(-e "$arg")) then
	if($arg =~ *.mtz) set infile = $arg
    endif
end

if(! -e "$infile") then
    echo "usage: $0 blah.mtz "
    echo "where: blah.mtz is the mtz file you want to convert to SOLVE format."
    exit 9
endif

# see if this is a merged, or unmerged file
echo "HEADER" | mtzdump hklin $infile |\
nawk '/^ H K L /{while(NF>1){printf "%s", $0; getline}; print ""} \
/^ H H H /{while(NF>1){printf "%s", $0; getline}; print ""}' |\
nawk '/^ H K L /{for(i=1;i<=NF;++i){++n;label[n]=$i}} \
      /^ H H H /{for(i=1;i<=NF;++i){if($i ~ /[JGK]/) print label[i], label[i+1]}}' |\
cat >! ${tempfile}labels

set I = `cat ${tempfile}labels`
if($#I > 3) then
    # this was a merged file
    set type = "pre"
    set I = "I(+) SIGI(+) I(-) SIGI(-)"
    set LABELS = "$I"
    set format = "3I5, 4F12.3"
    # Resolve version incompatibility here
    set temp = `echo "" | mtz2various | & nawk '/VERSION/{print $7*10}'`
    if("$temp" < 34) then
	set LABIN = "DUM1=I(+) DUM2=SIGI(+) DUM3=I(-) DUM4=SIGI(-)"
    else
	# make sure we get these labels right
	set LABIN = "I(+)=I(+) SIGI(+)=SIGI(+) I(-)=I(-) SIGI(-)=SIGI(-)"
    endif
else
    # unmerged file
    set type = "un"
    set format = "3I5, 2F12.3"
    set LABIN = "FP=$I[1] SIGFP=$I[2]"
    set LABELS = "$I[1] $I[2]"
endif
rm -f ${tempfile}labels

goto ReturnFromSetup

